@@ -54,6 +54,7 @@ import java.util.List;
 import com.openexchange.java.Strings;
 import com.openexchange.mobile.api.facade.connectors.responses.mtos.AccountMto;
 import com.openexchange.mobile.api.facade.connectors.responses.mtos.UserMto;
+import com.openexchange.mobile.api.facade.utils.AccountUtil;
 import com.openexchange.mobile.api.facade.utils.ListUtil;
 import com.openexchange.mobile.api.facade.utils.MapFunction;
 
@@ -97,7 +98,7 @@ public class Account {
     public Account(AccountMto accountMto, UserMto userMto, String defaultSendAddress, List<Folder> folders) {
         id = accountMto.getId();
         accountName = accountMto.getAccountName();
-        userName = getUserName(accountMto.getPersonalName(), userMto);
+        userName = AccountUtil.getUserName(accountMto.getPersonalName(), userMto);
         if (userMto != null) {
             firstName = userMto.getFirstName();
             lastName = userMto.getLastName();
@@ -111,7 +112,7 @@ public class Account {
             aliases = accountMto.getAliases();
         } else {
             primaryAddress = defaultSendAddress;
-            aliases = relaceAddress(accountMto.getAliases(), defaultSendAddress, accountPrimaryAddress);
+            aliases = replaceAddress(accountMto.getAliases(), defaultSendAddress, accountPrimaryAddress);
         }
         canSend = "0".equals(accountMto.getId()) || !Strings.isEmpty(accountMto.getTransportUrl());
         rootFolderId = accountMto.getRootFolderId();
@@ -127,27 +128,6 @@ public class Account {
         }
     }
 
-    private String getUserName(String personalName, UserMto userMto) {
-        String userName;
-        if (userMto == null) {
-            return personalName;
-        }
-        String firstName = userMto.getFirstName();
-        String lastName = userMto.getLastName();
-        if (firstName != null || lastName != null) {
-            if (firstName == null) {
-                userName = lastName;
-            } else if (lastName == null) {
-                userName = firstName;
-            } else {
-                userName = firstName + " " + lastName;
-            }
-        } else {
-            userName = Strings.isEmpty(personalName) ? userMto.getDisplayName() : personalName;
-        }
-        return userName;
-    }
-
     public Account withFolders(List<Folder> folders) {
         this.folders = folders;
         standardFolders = createStandardFolders(folders);
@@ -191,7 +171,7 @@ public class Account {
         return new StandardFolders(draftsFolder, inboxFolder, sentFolder, spamFolder, trashFolder, archiveFolder);
     }
 
-    private List<String> relaceAddress(List<String> addresses, final String toReplace, final String replacement) {
+    private List<String> replaceAddress(List<String> addresses, final String toReplace, final String replacement) {
         return ListUtil.map(addresses, new MapFunction<String, String>() {
 
             @Override
